@@ -19,8 +19,5 @@ package org.codehaus.plexus.metadata.gleaner;
 /**
  * ???
  *
- * @version $Id$
  */
-public class NoAnnotationsClass
-{
-}
+public class NoAnnotationsClass {}
